==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/mpc/translations/mpc_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="59"/>
        <source>Musepack Plugin</source>
        <translation>Musepack Module</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="61"/>
        <source>Musepack Files</source>
        <translation>Musepack Bestanden</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="125"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Over de Musepack Audio Module</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="126"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Musepack Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="127"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Sample frequentie</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/mpc/translations/mpc_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="53"/>
        <source>Musepack Plugin</source>
        <translation>Musepack Module</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="55"/>
        <source>Musepack Files</source>
        <translation>Musepack Bestanden</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="119"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Over de Musepack Audio Module</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="120"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Musepack Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="121"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Sample frequentie</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>
